==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/gl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade amósalle onde están almacenados os seus datos e quen pode acceder a eles, ben porque compartiu con eles ou porque son administradores.",
    "Remove external admin" : "Retirar administrador externo",
    "Add external admin" : "Engadir administrador externo",
    "Name of external admin" : "Nome do administrador externo",
    "This server is using full-disk-encryption." : "Este servidor está a usar o cifrado de disco completo.",
    "Your files are not protected by encryption." : "Os seus ficheiros non están protexidos con cifrado.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Os seus ficheiros están protexidos con {linkopen}cifrado no lado do servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protexido con cifrado de disco completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Os seus ficheiros están cifrados con {linkopen}cifrado no lado do servidor ↗{linkclose}. Ademais, este servidor está protexido con cifrado de disco completo.",
    "Your data is located in: " : "Os seus datos están localizados en:",
    "The admin hasn't selected the location of the server yet." : "O administrador aínda non seleccionou a localización do servidor.",
    "Change data location" : "Cambiar a localización dos datos",
    "Please select a region" : "Seleccione a rexión",
    "You don't have any shares with individual users." : "Non tes ningunha compartición con usuarios individuais.",
    "Somaliland" : "Somalia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antiga e Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Arxentina",
    "American Samoa" : "Samoa americana",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas de Åland",
    "Azerbaijan" : "Acerbaixán",
    "Bosnia and Herzegovina" : "Bosnia e Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomeu",
    "Bermuda" : "Bermudas",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio e Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Congo (República democrática do)",
    "Central African Republic" : "República Centro Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíza",
    "Cote d'Ivoire" : "Costa do Marfin",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Nadal",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemaña",
    "Djibouti" : "Xibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Alxeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exipto",
    "West Sahara" : "Sáhara Ocidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fidxi",
    "Falkland Islands" : "Illas Malvinas (Falkland)",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Illas Feroes",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Xeorxia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Xibraltar",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Xeorxia do Sur e as Illas Sandwich do Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bisau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illa Heard e Illas McDonald",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico do Océano Índico",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Quenia",
    "Kyrgyzstan" : "Quirguistán",
    "Cambodia" : "Camboxa",
    "Kiribati" : "Kiribatí",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "San Cristovo e Nevis",
    "North Korea" : "Corea do Norte",
    "South Korea" : "Corea do Sur",
    "Kuwait" : "Kuvait",
    "Cayman Islands" : "Illas Caimán",
    "Kazakhstan" : "Cazaquistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "San Martín (parte francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Malí",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Illas Marianas do Norte",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nova Caledonia",
    "Niger" : "Níxer",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Celandia",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papúa Nova Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "San Pedro e Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Réunion" : "Reunión",
    "Romania" : "Romanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomón",
    "Seychelles" : "Seicheles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascension e Tristán da Cuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Illas Svalbard e Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Mariño",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudán do Sur",
    "Sao Tome and Principe" : "San Tomé e Príncipe",
    "El Salvador" : "O Salvador",
    "Sint Maarten" : "San Martín (parte holandesa)",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Turks and Caicos Islands" : "Illas Turks e Caicos",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Terras Austrais e Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor do Leste",
    "Turkmenistan" : "Turquemenistán",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trindade e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illas exteriores menores dos Estados Unidos",
    "United States" : "Estados Unidos (de N A)",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Usbequistán",
    "Holy See" : "Cidade do Vaticano",
    "Saint Vincent and the Grenadines" : "San Vicente e as Grenadinas",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Illas Virxes, Británicas",
    "Virgin Islands (U.S.)" : "Illas Virxes (EE.UU.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Illas Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Maiote",
    "South Africa" : "Suráfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Cimbabue",
    "Your Nextcloud account" : "A súa conta de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Os seus datos representan quen é e é doado abusar deles. En Nextcloud cremos que ten dereito a decidir o que ocorre cos seus datos. Nextcloud protexe os seus dereitos tal e como se define no Manifiesto de datos do usuario.",
    "User Data Manifesto 2.0" : "Manifesto de datos do usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo dereitos básicos para que as persoas controlen os seus propios datos na era da Internet",
    "Control" : "Control",
    "over user data access" : "sobre o acceso aos datos do usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os datos enviados de forma explícita e voluntaria por un usuario deben estar baixo o control final do usuario. Os usuarios deben poder decidir a quen conceder acceso directo aos seus datos e con que permisos e licenzas se debe conceder ese acceso.",
    "Knowledge" : "Coñecemento",
    "of how the data is stored" : "de como se almacenan os datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cando os datos se envían a un provedor de servizos específico, os usuarios deben estar informados sobre o lugar onde o provedor de servizos específico almacena os datos, por canto tempo, en que xurisdición opera o provedor de servizos específico e cales son as leis aplicábeis.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escoller unha plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuarios sempre poderán extraer os seus datos do servizo en calquera momento sen experimentar ningún bloqueo de provedor. É necesario garantir estándares abertos para formatos e protocolos.",
    "Learn more ↗" : "Aprender máis ↗",
    "Where is your data?" : "Onde están os seus datos?",
    "Who has access to your data?" : "Quen ten acceso aos seus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Persoas coas que compartiu",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Lea a política de privacidade.",
    "Encryption" : "Cifrado",
    "Please select a country" : "Seleccione un país",
    "Bosnia and Herzegowina" : "Bosnia e Hercegovina"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/gl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade amósalle onde están almacenados os seus datos e quen pode acceder a eles, ben porque compartiu con eles ou porque son administradores.",
    "Remove external {propertyName} admin" : "Eliminar o administrador externo de {propertyName}",
    "Add external admin" : "Engadir administrador externo",
    "Name of external admin" : "Nome do administrador externo",
    "Adapt encryption" : "Adaptar o cifrado",
    "This server is using full-disk-encryption." : "Este servidor está a usar o cifrado de disco completo.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "O teu almacenamento doméstico está cifrado mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha chave mestra. Significa que os administradores poden acceder aos teus ficheiros, pero non ler o seu contido.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Os teus ficheiros en almacenamentos externos pódense cifrar mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha chave mestra en función da súa configuración.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "O almacenamento do teu fogar está cifrado mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha clave de usuario individual. Significa que os administradores poden acceder aos teus ficheiros, pero non ler o seu contido.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Os teus ficheiros en almacenamentos externos pódense cifrar mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha clave individual en función da súa configuración.",
    "Additionally, this server is protected with full-disk-encryption." : "Ademais, este servidor está protexido con cifrado de disco completo.",
    "This server is protected with full-disk-encryption." : "Este servidor está protexido con cifrado de disco completo.",
    "Your files are not protected by encryption." : "Os seus ficheiros non están protexidos con cifrado.",
    "Your data is located in:" : "Os seus datos atópanse en:",
    "The admin has not selected the location of the server yet." : "O administrador aínda non seleccionou a localización do servidor.",
    "Change data location" : "Cambiar a localización dos datos",
    "Please select a region" : "Seleccione a rexión",
    "You don't have any shares with individual users." : "Non tes ningunha compartición con usuarios individuais.",
    "Somaliland" : "Somalia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antiga e Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Arxentina",
    "American Samoa" : "Samoa americana",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas de Åland",
    "Azerbaijan" : "Acerbaixán",
    "Bosnia and Herzegovina" : "Bosnia e Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomeu",
    "Bermuda" : "Bermudas",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio e Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Democratic Republic of the Congo" : "Congo (República democrática do)",
    "Central African Republic" : "República Centro Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíza",
    "Cote d'Ivoire" : "Costa do Marfin",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Illa Nadal",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemaña",
    "Djibouti" : "Xibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Alxeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exipto",
    "West Sahara" : "Sáhara Ocidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fidxi",
    "Falkland Islands" : "Illas Malvinas (Falkland)",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Illas Feroes",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Xeorxia",
    "French Guiana" : "Guaiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Xibraltar",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Xeorxia do Sur e as Illas Sandwich do Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bisau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Illa Heard e Illas McDonald",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico do Océano Índico",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Quenia",
    "Kyrgyzstan" : "Quirguistán",
    "Cambodia" : "Camboxa",
    "Kiribati" : "Kiribatí",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "San Cristovo e Nevis",
    "North Korea" : "Corea do Norte",
    "South Korea" : "Corea do Sur",
    "Kuwait" : "Kuvait",
    "Cayman Islands" : "Illas Caimán",
    "Kazakhstan" : "Cazaquistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "San Martín (parte francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Malí",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Illas Marianas do Norte",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nova Caledonia",
    "Niger" : "Níxer",
    "Norfolk Island" : "Illa Norfolk",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nova Celandia",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papúa Nova Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "San Pedro e Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Réunion" : "Reunión",
    "Romania" : "Romanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomón",
    "Seychelles" : "Seicheles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascension e Tristán da Cuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Illas Svalbard e Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Mariño",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudán do Sur",
    "Sao Tome and Principe" : "San Tomé e Príncipe",
    "El Salvador" : "O Salvador",
    "Sint Maarten" : "San Martín (parte holandesa)",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Turks and Caicos Islands" : "Illas Turcas e Caicos",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Terras Austrais e Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor do Leste",
    "Turkmenistan" : "Turquemenistán",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trindade e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Illas exteriores menores dos Estados Unidos",
    "United States" : "Estados Unidos (de N A)",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Usbequistán",
    "Holy See" : "Santa Sé",
    "Saint Vincent and the Grenadines" : "San Vicente e as Grenadinas",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Illas Virxes, Británicas",
    "Virgin Islands (U.S.)" : "Illas Virxes (EE.UU.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Illas Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "Mayotte" : "Maiote",
    "South Africa" : "Suráfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Cimbabue",
    "Your %s account" : "A túa conta %s",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Os seus datos representan quen é e é doado abusar deles. En Nextcloud cremos que ten dereito a decidir o que ocorre cos seus datos. Nextcloud protexe os seus dereitos tal e como se define no Manifiesto de datos do usuario.",
    "User Data Manifesto 2.0" : "Manifesto de datos do usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo dereitos básicos para que as persoas controlen os seus propios datos na era da Internet",
    "Control" : "Control",
    "over user data access" : "sobre o acceso aos datos do usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os datos enviados de forma explícita e voluntaria por un usuario deben estar baixo o control final do usuario. Os usuarios deben poder decidir a quen conceder acceso directo aos seus datos e con que permisos e licenzas se debe conceder ese acceso.",
    "Knowledge" : "Coñecemento",
    "of how the data is stored" : "de como se almacenan os datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cando os datos se envían a un provedor de servizos específico, os usuarios deben estar informados sobre o lugar onde o provedor de servizos específico almacena os datos, por canto tempo, en que xurisdición opera o provedor de servizos específico e cales son as leis aplicábeis.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escoller unha plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuarios sempre poderán extraer os seus datos do servizo en calquera momento sen experimentar ningún bloqueo de provedor. É necesario garantir estándares abertos para formatos e protocolos.",
    "Learn more ↗" : "Aprender máis ↗",
    "Where is your data?" : "Onde están os seus datos?",
    "Who has access to your data?" : "Quen ten acceso aos seus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Persoas coas que compartiu",
    "Privacy policy" : "Directiva de privacidade",
    "Read the privacy policy." : "Lea a directiva de privacidade.",
    "Encryption" : "Cifrado",
    "Remove external admin" : "Retirar administrador externo",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "O teu almacenamento doméstico está cifrado mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha chave mestra.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "O almacenamento do teu fogar está cifrado mediante {linkopen}cifrado do lado do servidor ↗{linkclose} cunha clave de usuario individual."
},
"nplurals=2; plural=(n != 1);");
